import mix from 'polished/lib/color/mix';
import parseToRgb from 'polished/lib/color/parseToRgb';

import { colors, themeColors } from './defaultTheme';

var themeColorInterval = 0.08;

// Color contrast
export function colorYiq(color) {
  var r = parseToRgb(color).red;
  var g = parseToRgb(color).green;
  var b = parseToRgb(color).blue;

  var yiq = (r * 299 + g * 587 + b * 114) / 1000;

  if (yiq >= 150) {
    return '#111';
  }

  return '#fff';
}

// Retreive color
export function getColor() {
  var key = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'blue';

  return colors[key];
}

export function themeColor() {
  var key = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'primary';

  return themeColors[key];
}

// Request a theme color level
export function themeColorLevel() {
  var colorName = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 'primary';
  var level = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 0;

  var color = themeColor(colorName);
  var colorBase = level > 0 ? '#000' : '#fff';

  if (level < 0) {
    // Lighter values need a quick double negative for the Sass math to work
    return mix(level * -1 * themeColorInterval, colorBase, color);
  }

  return mix(level * themeColorInterval, colorBase, color);
}